==> 2.0.tar.gz: tegrarcmgui/TegraRcmGUI/resource.h <==
/ / { { N O _ D E P E N D E N C I E S } } 
 
 / /   M i c r o s o f t   V i s u a l   C + +   g e n e r a t e d   i n c l u d e   f i l e . 
 
 / /   U s e d   b y   T e g r a R c m G U I . r c 
 
 / / 
 
 # d e f i n e   I D M _ A B O U T B O X                                         0 x 0 0 1 0 
 
 # d e f i n e   I D S _ A B O U T B O X                                         1 0 1 
 
 # d e f i n e   I D D _ T E G R A R C M G U I _ D I A L O G                     1 0 2 
 
 # d e f i n e   I D R _ M A I N F R A M E                                       1 2 8 
 
 # d e f i n e   I D B _ B I T M A P 1                                           1 5 1 
 
 # d e f i n e   D R I V E R _ K O                                               1 5 7 
 
 # d e f i n e   I N I T _ L O G O                                               1 5 8 
 
 # d e f i n e   R C M _ D E T E C T E D                                         1 5 9 
 
 # d e f i n e   I D B _ B I T M A P 3                                           1 6 0 
 
 # d e f i n e   R C M _ N O T _ D E T E C T E D                                 1 6 0 
 
 # d e f i n e   L O A D I N G                                                   1 6 1 
 
 # d e f i n e   L O A D I N G 1                                                 1 6 2 
 
 # d e f i n e   L O A D E D                                                     1 6 2 
 
 # d e f i n e   L O A D _ E R R O R                                             1 6 3 
 
 # d e f i n e   I D _ T R A Y I C O N _ R C M                                   1 6 5 
 
 # d e f i n e   I D _ T R A Y I C O N _ N O _ R C M                             1 6 6 
 
 # d e f i n e   I D _ B R O W S E _ I C O N                                     1 6 7 
 
 # d e f i n e   I D D _ D I A L O G 1                                           1 7 1 
 
 # d e f i n e   I D _ D I A L O G T A B _ 0 1                                   1 7 1 
 
 # d e f i n e   I D D _ D I A L O G 2                                           1 7 2 
 
 # d e f i n e   I D _ D I A L O G T A B _ 0 2                                   1 7 2 
 
 # d e f i n e   I D _ D I A L O G T A B _ 0 3                                   1 7 3 
 
 # d e f i n e   I D _ S T A T U S _ I C O N                                     1 7 7 
 
 # d e f i n e   I D _ L I N U X _ I C O N                                       1 7 8 
 
 # d e f i n e   I D _ U M S T O O L _ I C O N                                   1 7 9 
 
 # d e f i n e   I D _ A D D _ I C O N                                           1 8 1 
 
 # d e f i n e   I D _ D E L E T E _ I C O N                                     1 8 2 
 
 # d e f i n e   I D C _ B U T T O N 1                                           1 0 0 1 
 
 # d e f i n e   I D C _ B R O W S E                                             1 0 0 1 
 
 # d e f i n e   I D _ I N S T A L L _ D R I V E R                               1 0 0 1 
 
 # d e f i n e   R E S L A B                                                     1 0 0 2 
 
 # d e f i n e   I D C _ B U T T O N 2                                           1 0 0 3 
 
 # d e f i n e   I D C _ M O U N T _ S D                                         1 0 0 3 
 
 # d e f i n e   I D _ A D D _ F A V                                             1 0 0 3 
 
 # d e f i n e   S W P I C                                                       1 0 0 4 
 
 # d e f i n e   I D _ D E L _ F A V                                             1 0 0 4 
 
 # d e f i n e   P A Y L O A D _ P A T H                                         1 0 0 5 
 
 # d e f i n e   P E R R O R                                                     1 0 0 5 
 
 # d e f i n e   I D C _ I N J E C T                                             1 0 0 8 
 
 # d e f i n e   I N F O _ L A B E L                                             1 0 0 9 
 
 # d e f i n e   R C M _ P I C _ 1                                               1 0 1 0 
 
 # d e f i n e   R C M _ P I C _ 2                                               1 0 1 1 
 
 # d e f i n e   R C M _ P I C _ 3                                               1 0 1 2 
 
 # d e f i n e   R C M _ P I C _ 4                                               1 0 1 3 
 
 # d e f i n e   R C M _ P I C _ 5                                               1 0 1 4 
 
 # d e f i n e   I D C _ S H O F E L 2                                           1 0 1 5 
 
 # d e f i n e   R C M _ P I C _ 6                                               1 0 1 6 
 
 # d e f i n e   I D C _ C H E C K 1                                             1 0 1 7 
 
 # d e f i n e   A U T O _ I N J E C T                                           1 0 1 7 
 
 # d e f i n e   R C M _ P I C _ 8                                               1 0 1 7 
 
 # d e f i n e   S T A T U S _ I C O N                                           1 0 1 7 
 
 # d e f i n e   R C M _ P I C _ 7                                               1 0 1 8 
 
 # d e f i n e   M I N _ T O _ T R A Y                                           1 0 1 8 
 
 # d e f i n e   I D C _ M F C L I N K 1                                         1 0 1 9 
 
 # d e f i n e   I D C _ R I C H E D I T 2 1                                     1 0 2 0 
 
 # d e f i n e   I D C _ R A J K O S T O                                         1 0 2 1 
 
 # d e f i n e   S E P A R A T O R                                               1 0 2 2 
 
 # d e f i n e   I D C _ R A J K O S T O 2                                       1 0 2 2 
 
 # d e f i n e   I D _ T R A Y _ A P P _ I C O N                                 1 0 2 3 
 
 # d e f i n e   I D C _ T A B _ C O N T R O L                                   1 0 2 3 
 
 # d e f i n e   I D _ T R A Y _ E X I T                                         1 0 2 4 
 
 # d e f i n e   I D C _ L I S T 1                                               1 0 2 4 
 
 # d e f i n e   W M _ S Y S I C O N                                             1 0 2 5 
 
 # d e f i n e   I D C _ S T A T U S                                             1 0 2 5 
 
 # d e f i n e   V A L I D                                                       1 0 2 6 
 
 # d e f i n e   I D C _ S T A T U S _ B G                                       1 0 2 6 
 
 # d e f i n e   I N V A L I D                                                   1 0 2 7 
 
 # d e f i n e   N E U T R A L                                                   1 0 2 8 
 
 # d e f i n e   I D _ U M S T O O L _ T I T L E                                 1 0 3 0 
 
 # d e f i n e   I D _ L I N U X _ T I T L E                                     1 0 3 1 
 
 # d e f i n e   I D _ S E L E C T _ P A Y L O A D                               1 0 3 2 
 
 # d e f i n e   I D _ F A V O R I T E S _ T I T L E                             1 0 3 3 
 
 # d e f i n e   I D _ S Y S T E M T R A Y                                       0 x 1 2 3 4 
 
 # d e f i n e   S W M _ S H O W                                                 0 x 1 2 3 5 
 
 # d e f i n e   S W M _ H I D E                                                 0 x 1 2 3 6 
 
 # d e f i n e   S W M _ E X I T                                                 0 x 1 2 3 7 
 
 # d e f i n e   S W M _ I N J E C T                                             0 x 1 2 3 8 
 
 # d e f i n e   S W M _ M O U N T                                               0 x 1 2 3 9 
 
 # d e f i n e   S W M _ L I N U X                                               0 x 1 2 4 0 
 
 # d e f i n e   S W M _ B R O W S E                                             0 x 1 2 4 1 
 
 
 
 / /   N e x t   d e f a u l t   v a l u e s   f o r   n e w   o b j e c t s 
 
 / /   
 
 # i f d e f   A P S T U D I O _ I N V O K E D 
 
 # i f n d e f   A P S T U D I O _ R E A D O N L Y _ S Y M B O L S 
 
 # d e f i n e   _ A P S _ N E X T _ R E S O U R C E _ V A L U E                 1 8 3 
 
 # d e f i n e   _ A P S _ N E X T _ C O M M A N D _ V A L U E                   3 2 7 7 2 
 
 # d e f i n e   _ A P S _ N E X T _ C O N T R O L _ V A L U E                   1 0 3 4 
 
 # d e f i n e   _ A P S _ N E X T _ S Y M E D _ V A L U E                       1 0 1 
 
 # e n d i f 
 
 # e n d i f 
 
 

==> 2.4.tar.gz: tegrarcmgui/TegraRcmGUI/resource.h <==
/ / { { N O _ D E P E N D E N C I E S } } 
 
 / /   M i c r o s o f t   V i s u a l   C + +   g e n e r a t e d   i n c l u d e   f i l e . 
 
 / /   U s e d   b y   T e g r a R c m G U I . r c 
 
 / / 
 
 # d e f i n e   I D M _ A B O U T B O X                                         0 x 0 0 1 0 
 
 # d e f i n e   I D S _ A B O U T B O X                                         1 0 1 
 
 # d e f i n e   I D D _ T E G R A R C M G U I _ D I A L O G                     1 0 2 
 
 # d e f i n e   I D R _ M A I N F R A M E                                       1 2 8 
 
 # d e f i n e   I D B _ B I T M A P 1                                           1 5 1 
 
 # d e f i n e   D R I V E R _ K O                                               1 5 7 
 
 # d e f i n e   I N I T _ L O G O                                               1 5 8 
 
 # d e f i n e   R C M _ D E T E C T E D                                         1 5 9 
 
 # d e f i n e   I D B _ B I T M A P 3                                           1 6 0 
 
 # d e f i n e   R C M _ N O T _ D E T E C T E D                                 1 6 0 
 
 # d e f i n e   L O A D I N G                                                   1 6 1 
 
 # d e f i n e   L O A D I N G 1                                                 1 6 2 
 
 # d e f i n e   L O A D E D                                                     1 6 2 
 
 # d e f i n e   L O A D _ E R R O R                                             1 6 3 
 
 # d e f i n e   I D _ T R A Y I C O N _ R C M                                   1 6 5 
 
 # d e f i n e   I D _ T R A Y I C O N _ N O _ R C M                             1 6 6 
 
 # d e f i n e   I D _ B R O W S E _ I C O N                                     1 6 7 
 
 # d e f i n e   I D D _ D I A L O G 1                                           1 7 1 
 
 # d e f i n e   I D _ D I A L O G T A B _ 0 1                                   1 7 1 
 
 # d e f i n e   I D D _ D I A L O G 2                                           1 7 2 
 
 # d e f i n e   I D _ D I A L O G T A B _ 0 2                                   1 7 2 
 
 # d e f i n e   I D _ D I A L O G T A B _ 0 3                                   1 7 3 
 
 # d e f i n e   I D _ S T A T U S _ I C O N                                     1 7 7 
 
 # d e f i n e   I D _ L I N U X _ I C O N                                       1 7 8 
 
 # d e f i n e   I D _ U M S T O O L _ I C O N                                   1 7 9 
 
 # d e f i n e   I D _ A D D _ I C O N                                           1 8 1 
 
 # d e f i n e   I D _ D E L E T E _ I C O N                                     1 8 2 
 
 # d e f i n e   D R I V E R _ K O _ 2                                           1 8 3 
 
 # d e f i n e   L O A D _ E R R O R _ 2                                         1 8 4 
 
 # d e f i n e   I N I T _ L O G O _ 2                                           1 8 5 
 
 # d e f i n e   L O A D I N G _ 2                                               1 8 7 
 
 # d e f i n e   R C M _ D E T E C T E D _ 2                                     1 8 8 
 
 # d e f i n e   R C M _ N O T _ D E T E C T E D _ 2                             1 9 0 
 
 # d e f i n e   I D C _ B U T T O N 1                                           1 0 0 1 
 
 # d e f i n e   I D C _ B R O W S E                                             1 0 0 1 
 
 # d e f i n e   I D _ I N S T A L L _ D R I V E R                               1 0 0 1 
 
 # d e f i n e   L O A D E D _ 2                                                 1 0 0 1 
 
 # d e f i n e   R E S L A B                                                     1 0 0 2 
 
 # d e f i n e   I D C _ B U T T O N 2                                           1 0 0 3 
 
 # d e f i n e   I D C _ M O U N T _ S D                                         1 0 0 3 
 
 # d e f i n e   I D _ A D D _ F A V                                             1 0 0 3 
 
 # d e f i n e   S W P I C                                                       1 0 0 4 
 
 # d e f i n e   I D _ D E L _ F A V                                             1 0 0 4 
 
 # d e f i n e   P A Y L O A D _ P A T H                                         1 0 0 5 
 
 # d e f i n e   P E R R O R                                                     1 0 0 5 
 
 # d e f i n e   I D C _ I N J E C T                                             1 0 0 8 
 
 # d e f i n e   I N F O _ L A B E L                                             1 0 0 9 
 
 # d e f i n e   R C M _ P I C _ 1                                               1 0 1 0 
 
 # d e f i n e   R C M _ P I C _ 2                                               1 0 1 1 
 
 # d e f i n e   R C M _ P I C _ 3                                               1 0 1 2 
 
 # d e f i n e   R C M _ P I C _ 4                                               1 0 1 3 
 
 # d e f i n e   R C M _ P I C _ 5                                               1 0 1 4 
 
 # d e f i n e   I D C _ S H O F E L 2                                           1 0 1 5 
 
 # d e f i n e   R C M _ P I C _ 6                                               1 0 1 6 
 
 # d e f i n e   I D C _ C H E C K 1                                             1 0 1 7 
 
 # d e f i n e   A U T O _ I N J E C T                                           1 0 1 7 
 
 # d e f i n e   R C M _ P I C _ 8                                               1 0 1 7 
 
 # d e f i n e   S T A T U S _ I C O N                                           1 0 1 7 
 
 # d e f i n e   R C M _ P I C _ 7                                               1 0 1 8 
 
 # d e f i n e   M I N _ T O _ T R A Y                                           1 0 1 8 
 
 # d e f i n e   I D C _ M F C L I N K 1                                         1 0 1 9 
 
 # d e f i n e   R U N _ W I N S T A T R T                                       1 0 1 9 
 
 # d e f i n e   R U N _ W I N S T A R T                                         1 0 1 9 
 
 # d e f i n e   I D C _ R I C H E D I T 2 1                                     1 0 2 0 
 
 # d e f i n e   I D C _ R C M B G                                               1 0 2 0 
 
 # d e f i n e   I D C _ R A J K O S T O                                         1 0 2 1 
 
 # d e f i n e   S E P A R A T O R                                               1 0 2 2 
 
 # d e f i n e   I D _ T R A Y _ A P P _ I C O N                                 1 0 2 3 
 
 # d e f i n e   I D C _ T A B _ C O N T R O L                                   1 0 2 3 
 
 # d e f i n e   I D _ T R A Y _ E X I T                                         1 0 2 4 
 
 # d e f i n e   I D C _ L I S T 1                                               1 0 2 4 
 
 # d e f i n e   W M _ S Y S I C O N                                             1 0 2 5 
 
 # d e f i n e   I D C _ S T A T U S                                             1 0 2 5 
 
 # d e f i n e   V A L I D                                                       1 0 2 6 
 
 # d e f i n e   I D C _ S T A T U S _ B G                                       1 0 2 6 
 
 # d e f i n e   I N V A L I D                                                   1 0 2 7 
 
 # d e f i n e   N E U T R A L                                                   1 0 2 8 
 
 # d e f i n e   I D C _ R C M _ B G                                             1 0 2 9 
 
 # d e f i n e   I D _ U M S T O O L _ T I T L E                                 1 0 3 0 
 
 # d e f i n e   I D _ L I N U X _ T I T L E                                     1 0 3 1 
 
 # d e f i n e   I D _ S E L E C T _ P A Y L O A D                               1 0 3 2 
 
 # d e f i n e   I D _ F A V O R I T E S _ T I T L E                             1 0 3 3 
 
 # d e f i n e   R C M _ B I T M A P                                             1 0 3 4 
 
 # d e f i n e   R C M _ N O T _ D E T E C T E D 2                               1 0 3 5 
 
 # d e f i n e   I D _ S Y S T E M T R A Y                                       0 x 1 2 3 4 
 
 # d e f i n e   S W M _ S H O W                                                 0 x 1 2 3 5 
 
 # d e f i n e   S W M _ H I D E                                                 0 x 1 2 3 6 
 
 # d e f i n e   S W M _ E X I T                                                 0 x 1 2 3 7 
 
 # d e f i n e   S W M _ I N J E C T                                             0 x 1 2 3 8 
 
 # d e f i n e   S W M _ M O U N T                                               0 x 1 2 3 9 
 
 # d e f i n e   S W M _ L I N U X                                               0 x 1 2 4 0 
 
 # d e f i n e   S W M _ B R O W S E                                             0 x 1 2 4 1 
 
 # d e f i n e   S W M _ F A V 0 1                                               0 x 1 2 4 3 
 
 # d e f i n e   S W M _ F A V 0 2                                               0 x 1 2 4 4 
 
 # d e f i n e   S W M _ F A V 0 3                                               0 x 1 2 4 5 
 
 # d e f i n e   S W M _ F A V 0 4                                               0 x 1 2 4 6 
 
 # d e f i n e   S W M _ F A V 0 5                                               0 x 1 2 4 7 
 
 # d e f i n e   S W M _ F A V 0 6                                               0 x 1 2 4 8 
 
 # d e f i n e   S W M _ F A V 0 7                                               0 x 1 2 4 9 
 
 # d e f i n e   S W M _ F A V 0 8                                               0 x 1 2 5 0 
 
 # d e f i n e   S W M _ F A V 0 9                                               0 x 1 2 5 1 
 
 # d e f i n e   S W M _ F A V 1 0                                               0 x 1 2 5 2 
 
 # d e f i n e   S W M _ A U T O I N J E C T                                     0 x 1 2 5 4 
 
 
 
 / /   N e x t   d e f a u l t   v a l u e s   f o r   n e w   o b j e c t s 
 
 / /   
 
 # i f d e f   A P S T U D I O _ I N V O K E D 
 
 # i f n d e f   A P S T U D I O _ R E A D O N L Y _ S Y M B O L S 
 
 # d e f i n e   _ A P S _ N E X T _ R E S O U R C E _ V A L U E                 1 9 1 
 
 # d e f i n e   _ A P S _ N E X T _ C O M M A N D _ V A L U E                   3 2 7 7 2 
 
 # d e f i n e   _ A P S _ N E X T _ C O N T R O L _ V A L U E                   1 0 3 5 
 
 # d e f i n e   _ A P S _ N E X T _ S Y M E D _ V A L U E                       1 0 1 
 
 # e n d i f 
 
 # e n d i f 
 
 
